@@ -257,85 +257,16 @@ conn_request(void *ptr, http_request_t *request, http_response_t **response) {
     } else if (!strcmp(method, "RECORD")) {
         handler = &raop_handler_record;
     } else if (!strcmp(method, "FLUSH")) {
-        const char *rtpinfo;
-        int next_seq = -1;
-
-        rtpinfo = http_request_get_header(request, "RTP-Info");
-        if (rtpinfo) {
-            logger_log(conn->raop->logger, LOGGER_DEBUG, "Flush with RTP-Info: %s", rtpinfo);
-            if (!strncmp(rtpinfo, "seq=", 4)) {
-                next_seq = strtol(rtpinfo + 4, NULL, 10);
-            }
-        }
-        if (conn->raop_rtp) {
-            raop_rtp_flush(conn->raop_rtp, next_seq);
-        } else {
-            logger_log(conn->raop->logger, LOGGER_WARNING, "RAOP not initialized at FLUSH");
-        }
+        handler = &raop_handler_flush;
     } else if (!strcmp(method, "TEARDOWN")) {
-        /* get the teardown request type(s):  (type 96, 110, or none) */
-        const char *data;
-        int data_len;
-        bool teardown_96 = false, teardown_110 = false;
-        data = http_request_get_data(request, &data_len);
-        plist_t req_root_node = NULL;
-        plist_from_bin(data, data_len, &req_root_node);
-        char * plist_xml;
-        uint32_t plist_len;
-        plist_to_xml(req_root_node, &plist_xml, &plist_len);
-        logger_log(conn->raop->logger, LOGGER_DEBUG, "%s", plist_xml);
-        free(plist_xml);
-        plist_t req_streams_node = plist_dict_get_item(req_root_node, "streams");
-        /* Process stream teardown requests */
-        if (PLIST_IS_ARRAY(req_streams_node)) {
-            uint64_t val;
-            int count = plist_array_get_size(req_streams_node);
-            for (int i = 0; i < count; i++) {
-                plist_t req_stream_node = plist_array_get_item(req_streams_node,0);
-                plist_t req_stream_type_node = plist_dict_get_item(req_stream_node, "type");
-                plist_get_uint_val(req_stream_type_node, &val);
-                if (val == 96) {
-                    teardown_96 = true;
-                } else if (val == 110) { 
-                    teardown_110 = true;
-                }
-	    }
-        }
-        plist_free(req_root_node);
-        if (conn->raop->callbacks.conn_teardown) {
-             conn->raop->callbacks.conn_teardown(conn->raop->callbacks.cls, &teardown_96, &teardown_110);
-        }
-        logger_log(conn->raop->logger, LOGGER_DEBUG, "TEARDOWN request,  96=%d, 110=%d", teardown_96, teardown_110);
-
-        http_response_add_header(*response, "Connection", "close");
-
-        if (teardown_96) {
-            if (conn->raop_rtp) {
-	        /* Stop our audio RTP session */
-                raop_rtp_stop(conn->raop_rtp);
-            }
-        } else if (teardown_110) {
-            if (conn->raop_rtp_mirror) {
-                /* Stop our video RTP session */
-                raop_rtp_mirror_stop(conn->raop_rtp_mirror);
-            }
-        } else {
-            /* Destroy our sessions */
-            if (conn->raop_rtp) {
-                raop_rtp_destroy(conn->raop_rtp);
-                conn->raop_rtp = NULL;
-            }
-            if (conn->raop_rtp_mirror) {
-                raop_rtp_mirror_destroy(conn->raop_rtp_mirror);
-                conn->raop_rtp_mirror = NULL;
-            }
-        }
+        handler = &raop_handler_teardown;
+    } else {
+        logger_log(conn->raop->logger, LOGGER_INFO, "Unhandled Client Request: %s %s", method, url);
     }
+
     if (handler != NULL) {
         handler(conn, request, *response, &response_data, &response_datalen);
     }
-
-    
     http_response_finish(*response, response_data, response_datalen);
 
     int len;
@@ -411,15 +342,10 @@ conn_destroy(void *ptr) {
 }
 
 raop_t *
-raop_init(int max_clients, raop_callbacks_t *callbacks, const char *device_id, const char *keyfile) {
+raop_init(raop_callbacks_t *callbacks) {
     raop_t *raop;
-    pairing_t *pairing;
-    httpd_t *httpd;
-    httpd_callbacks_t httpd_cbs;
 
     assert(callbacks);
-    assert(max_clients > 0);
-    assert(max_clients < 100);
 
     /* Initialize the network */
     if (netutils_init() < 0) {
@@ -441,46 +367,8 @@ raop_init(int max_clients, raop_callbacks_t *callbacks, const char *device_id, c
     /* Initialize the logger */
     raop->logger = logger_init();
 
-    /* create a new public key for pairing */
-    int new_key;
-    pairing = pairing_init_generate(device_id, keyfile, &new_key);
-    if (!pairing) {
-        free(raop);
-        return NULL;
-    }
-    /* store PK as a string in raop->pk_str */
-    memset(raop->pk_str, 0, sizeof(raop->pk_str));
-#ifdef PK
-    strncpy(raop->pk_str, PK, 2*ED25519_KEY_SIZE);
-#else
-    unsigned char public_key[ED25519_KEY_SIZE];
-    pairing_get_public_key(pairing, public_key);
-    char *pk_str = utils_pk_to_string(public_key, ED25519_KEY_SIZE);
-    strncpy(raop->pk_str, (const char *) pk_str, 2*ED25519_KEY_SIZE);
-    free(pk_str);
-#endif
-    if (new_key) {
-        printf("*** A new Public Key has been created and stored in %s\n", keyfile);
-    }
-    
-    /* Set HTTP callbacks to our handlers */
-    memset(&httpd_cbs, 0, sizeof(httpd_cbs));
-    httpd_cbs.opaque = raop;
-    httpd_cbs.conn_init = &conn_init;
-    httpd_cbs.conn_request = &conn_request;
-    httpd_cbs.conn_destroy = &conn_destroy;
-
-    /* Initialize the http daemon */
-    httpd = httpd_init(raop->logger, &httpd_cbs, max_clients);
-    if (!httpd) {
-        pairing_destroy(pairing);
-        free(raop);
-        return NULL;
-    }
     /* Copy callbacks structure */
     memcpy(&raop->callbacks, callbacks, sizeof(raop_callbacks_t));
-    raop->pairing = pairing;
-    raop->httpd = httpd;
 
     /* initialize network port list */ 
     raop->port = 0;    
@@ -509,6 +397,57 @@ raop_init(int max_clients, raop_callbacks_t *callbacks, const char *device_id, c
     return raop;
 }
 
+int
+raop_init2(raop_t *raop, int max_clients, const char *device_id, const char *keyfile) {
+    pairing_t *pairing;
+    httpd_t *httpd;
+    httpd_callbacks_t httpd_cbs;
+
+    assert(max_clients > 0);
+    assert(max_clients < 100);
+
+    /* create a new public key for pairing */
+    int new_key;
+    pairing = pairing_init_generate(device_id, keyfile, &new_key);
+    if (!pairing) {
+        logger_log(raop->logger, LOGGER_ERR, "failed to create new public key for pairing");
+        return -1;
+    }
+    /* store PK as a string in raop->pk_str */
+    memset(raop->pk_str, 0, sizeof(raop->pk_str));
+#ifdef PK
+    strncpy(raop->pk_str, PK, 2*ED25519_KEY_SIZE);
+#else
+    unsigned char public_key[ED25519_KEY_SIZE];
+    pairing_get_public_key(pairing, public_key);
+    char *pk_str = utils_pk_to_string(public_key, ED25519_KEY_SIZE);
+    strncpy(raop->pk_str, (const char *) pk_str, 2*ED25519_KEY_SIZE);
+    free(pk_str);
+#endif
+    if (new_key) {
+        logger_log(raop->logger, LOGGER_INFO,"*** A new Public Key has been created and stored in %s", keyfile);
+    }
+
+    /* Set HTTP callbacks to our handlers */
+    memset(&httpd_cbs, 0, sizeof(httpd_cbs));
+    httpd_cbs.opaque = raop;
+    httpd_cbs.conn_init = &conn_init;
+    httpd_cbs.conn_request = &conn_request;
+    httpd_cbs.conn_destroy = &conn_destroy;
+
+    /* Initialize the http daemon */
+    httpd = httpd_init(raop->logger, &httpd_cbs, max_clients);
+    if (!httpd) {
+        logger_log(raop->logger, LOGGER_ERR, "failed to initialize http daemon");
+        pairing_destroy(pairing);
+        return -1;
+    }
+
+    raop->pairing = pairing;
+    raop->httpd = httpd;
+    return 0;
+}
+
 void
 raop_destroy(raop_t *raop) {
     if (raop) {
